# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datasource.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import kismet_pb2 as kismet__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='datasource.proto',
  package='KismetDatasource',
  syntax='proto2',
  serialized_pb=_b('\n\x10\x64\x61tasource.proto\x12\x10KismetDatasource\x1a\x0ckismet.proto\"\x1f\n\x0bSubChannels\x12\x10\n\x08\x63hannels\x18\x01 \x03(\t\"\x1d\n\nSubChanset\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\t\"c\n\nSubChanhop\x12\x10\n\x08\x63hannels\x18\x01 \x03(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x01\x12\x0f\n\x07shuffle\x18\x03 \x01(\x08\x12\x14\n\x0cshuffle_skip\x18\x04 \x01(\r\x12\x0e\n\x06offset\x18\x05 \x01(\r\"\xc8\x01\n\x06SubGps\x12\x0b\n\x03lat\x18\x01 \x02(\x01\x12\x0b\n\x03lon\x18\x02 \x02(\x01\x12\x0b\n\x03\x61lt\x18\x03 \x02(\x01\x12\r\n\x05speed\x18\x04 \x02(\x01\x12\x0f\n\x07heading\x18\x05 \x02(\x01\x12\x11\n\tprecision\x18\x06 \x02(\x01\x12\x0b\n\x03\x66ix\x18\x07 \x02(\r\x12\x10\n\x08time_sec\x18\x08 \x02(\x04\x12\x11\n\ttime_usec\x18\t \x02(\x04\x12\x0c\n\x04type\x18\n \x02(\t\x12\x0c\n\x04name\x18\x0b \x02(\t\x12\x16\n\x0ehigh_prec_time\x18\x0c \x01(\x01\"B\n\x0cSubInterface\x12\x11\n\tinterface\x18\x01 \x02(\t\x12\r\n\x05\x66lags\x18\x02 \x02(\t\x12\x10\n\x08hardware\x18\x03 \x01(\t\"Y\n\tSubPacket\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0b\n\x03\x64lt\x18\x03 \x02(\r\x12\x0c\n\x04size\x18\x04 \x02(\x04\x12\x0c\n\x04\x64\x61ta\x18\x05 \x02(\x0c\"J\n\x07SubJson\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0c\n\x04type\x18\x03 \x02(\t\x12\x0c\n\x04json\x18\x04 \x02(\t\"N\n\tSubBuffer\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0c\n\x04type\x18\x03 \x02(\t\x12\x0e\n\x06\x62uffer\x18\x04 \x02(\x0c\"\x90\x01\n\tSubSignal\x12\x12\n\nsignal_dbm\x18\x01 \x01(\x01\x12\x11\n\tnoise_dbm\x18\x02 \x01(\x01\x12\x13\n\x0bsignal_rssi\x18\x03 \x01(\x01\x12\x12\n\nnoise_rssi\x18\x04 \x01(\x01\x12\x10\n\x08\x66req_khz\x18\x05 \x01(\x01\x12\x0f\n\x07\x63hannel\x18\x06 \x01(\t\x12\x10\n\x08\x64\x61tarate\x18\x07 \x01(\x01\"\x9f\x01\n\nSubSpecset\x12\x11\n\tstart_mhz\x18\x01 \x01(\x01\x12\x0f\n\x07\x65nd_mhz\x18\x02 \x01(\x01\x12\x1a\n\x12samples_per_bucket\x18\x03 \x01(\x01\x12\x17\n\x0f\x62ucket_width_hz\x18\x04 \x01(\x01\x12\x12\n\nenable_amp\x18\x05 \x01(\x08\x12\x0e\n\x06if_amp\x18\x06 \x01(\x04\x12\x14\n\x0c\x62\x61seband_amp\x18\x07 \x01(\x04\"}\n\x0bSubSpectrum\x12\x10\n\x08time_sec\x18\x01 \x01(\x04\x12\x11\n\ttime_usec\x18\x02 \x01(\x04\x12\x11\n\tstart_mhz\x18\x03 \x01(\x01\x12\x0f\n\x07\x65nd_mhz\x18\x04 \x01(\x01\x12\x17\n\x0f\x62ucket_width_hz\x18\x05 \x01(\x01\x12\x0c\n\x04\x64\x61ta\x18\x06 \x03(\x05\",\n\nSubSuccess\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\r\n\x05seqno\x18\x02 \x02(\r\"\x11\n\x0f\x43loseDatasource\"\x99\x01\n\tConfigure\x12-\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12-\n\x07hopping\x18\x02 \x01(\x0b\x32\x1c.KismetDatasource.SubChanhop\x12.\n\x08spectrum\x18\x03 \x01(\x0b\x32\x1c.KismetDatasource.SubSpecset\"\xdf\x01\n\x0f\x43onfigureReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12-\n\x07hopping\x18\x03 \x01(\x0b\x32\x1c.KismetDatasource.SubChanhop\x12.\n\x07message\x18\x04 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12\x0f\n\x07warning\x18\x05 \x01(\t\"\xed\x02\n\nDataReport\x12%\n\x03gps\x18\x01 \x01(\x0b\x32\x18.KismetDatasource.SubGps\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12+\n\x06packet\x18\x03 \x01(\x0b\x32\x1b.KismetDatasource.SubPacket\x12+\n\x06signal\x18\x04 \x01(\x0b\x32\x1b.KismetDatasource.SubSignal\x12/\n\x08spectrum\x18\x05 \x01(\x0b\x32\x1d.KismetDatasource.SubSpectrum\x12\x0f\n\x07warning\x18\x06 \x01(\t\x12\'\n\x04json\x18\x07 \x01(\x0b\x32\x19.KismetDatasource.SubJson\x12+\n\x06\x62uffer\x18\x08 \x01(\x0b\x32\x1b.KismetDatasource.SubBuffer\x12\x16\n\x0ehigh_prec_time\x18\t \x01(\x01\"l\n\x0b\x45rrorReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\"\x10\n\x0eListInterfaces\"\xa5\x01\n\x10InterfacesReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12\x32\n\ninterfaces\x18\x03 \x03(\x0b\x32\x1e.KismetDatasource.SubInterface\"A\n\tNewSource\x12\x12\n\ndefinition\x18\x01 \x02(\t\x12\x12\n\nsourcetype\x18\x02 \x02(\t\x12\x0c\n\x04uuid\x18\x03 \x02(\t\" \n\nOpenSource\x12\x12\n\ndefinition\x18\x01 \x02(\t\"\x8c\x03\n\x10OpenSourceReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12\x0b\n\x03\x64lt\x18\x02 \x01(\r\x12\x19\n\x11\x63\x61pture_interface\x18\x03 \x01(\t\x12/\n\x08\x63hannels\x18\x04 \x01(\x0b\x32\x1d.KismetDatasource.SubChannels\x12-\n\x07\x63hannel\x18\x05 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12\x30\n\nhop_config\x18\x06 \x01(\x0b\x32\x1c.KismetDatasource.SubChanhop\x12\x10\n\x08hardware\x18\x07 \x01(\t\x12.\n\x07message\x18\x08 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12.\n\x08spectrum\x18\t \x01(\x0b\x32\x1c.KismetDatasource.SubSpecset\x12\x0c\n\x04uuid\x18\n \x01(\t\x12\x0f\n\x07warning\x18\x0b \x01(\t\"!\n\x0bProbeSource\x12\x12\n\ndefinition\x18\x01 \x02(\t\"\x94\x02\n\x11ProbeSourceReport\x12-\n\x07success\x18\x01 \x02(\x0b\x32\x1c.KismetDatasource.SubSuccess\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12/\n\x08\x63hannels\x18\x03 \x01(\x0b\x32\x1d.KismetDatasource.SubChannels\x12-\n\x07\x63hannel\x18\x04 \x01(\x0b\x32\x1c.KismetDatasource.SubChanset\x12.\n\x08spectrum\x18\x05 \x01(\x0b\x32\x1c.KismetDatasource.SubSpecset\x12\x10\n\x08hardware\x18\x06 \x01(\t\" \n\rWarningReport\x12\x0f\n\x07warning\x18\x01 \x02(\t')
  ,
  dependencies=[kismet__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SUBCHANNELS = _descriptor.Descriptor(
  name='SubChannels',
  full_name='KismetDatasource.SubChannels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.SubChannels.channels', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=83,
)


_SUBCHANSET = _descriptor.Descriptor(
  name='SubChanset',
  full_name='KismetDatasource.SubChanset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.SubChanset.channel', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=114,
)


_SUBCHANHOP = _descriptor.Descriptor(
  name='SubChanhop',
  full_name='KismetDatasource.SubChanhop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.SubChanhop.channels', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='KismetDatasource.SubChanhop.rate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shuffle', full_name='KismetDatasource.SubChanhop.shuffle', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shuffle_skip', full_name='KismetDatasource.SubChanhop.shuffle_skip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='KismetDatasource.SubChanhop.offset', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=215,
)


_SUBGPS = _descriptor.Descriptor(
  name='SubGps',
  full_name='KismetDatasource.SubGps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='KismetDatasource.SubGps.lat', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='KismetDatasource.SubGps.lon', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alt', full_name='KismetDatasource.SubGps.alt', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speed', full_name='KismetDatasource.SubGps.speed', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heading', full_name='KismetDatasource.SubGps.heading', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='precision', full_name='KismetDatasource.SubGps.precision', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fix', full_name='KismetDatasource.SubGps.fix', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubGps.time_sec', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubGps.time_usec', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetDatasource.SubGps.type', index=9,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='KismetDatasource.SubGps.name', index=10,
      number=11, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='high_prec_time', full_name='KismetDatasource.SubGps.high_prec_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=418,
)


_SUBINTERFACE = _descriptor.Descriptor(
  name='SubInterface',
  full_name='KismetDatasource.SubInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface', full_name='KismetDatasource.SubInterface.interface', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='KismetDatasource.SubInterface.flags', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='KismetDatasource.SubInterface.hardware', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=486,
)


_SUBPACKET = _descriptor.Descriptor(
  name='SubPacket',
  full_name='KismetDatasource.SubPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubPacket.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubPacket.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dlt', full_name='KismetDatasource.SubPacket.dlt', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='KismetDatasource.SubPacket.size', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='KismetDatasource.SubPacket.data', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=577,
)


_SUBJSON = _descriptor.Descriptor(
  name='SubJson',
  full_name='KismetDatasource.SubJson',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubJson.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubJson.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetDatasource.SubJson.type', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='json', full_name='KismetDatasource.SubJson.json', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=653,
)


_SUBBUFFER = _descriptor.Descriptor(
  name='SubBuffer',
  full_name='KismetDatasource.SubBuffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubBuffer.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubBuffer.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetDatasource.SubBuffer.type', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='KismetDatasource.SubBuffer.buffer', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=733,
)


_SUBSIGNAL = _descriptor.Descriptor(
  name='SubSignal',
  full_name='KismetDatasource.SubSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signal_dbm', full_name='KismetDatasource.SubSignal.signal_dbm', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='noise_dbm', full_name='KismetDatasource.SubSignal.noise_dbm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal_rssi', full_name='KismetDatasource.SubSignal.signal_rssi', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='noise_rssi', full_name='KismetDatasource.SubSignal.noise_rssi', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='freq_khz', full_name='KismetDatasource.SubSignal.freq_khz', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.SubSignal.channel', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='datarate', full_name='KismetDatasource.SubSignal.datarate', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=880,
)


_SUBSPECSET = _descriptor.Descriptor(
  name='SubSpecset',
  full_name='KismetDatasource.SubSpecset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_mhz', full_name='KismetDatasource.SubSpecset.start_mhz', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_mhz', full_name='KismetDatasource.SubSpecset.end_mhz', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='samples_per_bucket', full_name='KismetDatasource.SubSpecset.samples_per_bucket', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bucket_width_hz', full_name='KismetDatasource.SubSpecset.bucket_width_hz', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enable_amp', full_name='KismetDatasource.SubSpecset.enable_amp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='if_amp', full_name='KismetDatasource.SubSpecset.if_amp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='baseband_amp', full_name='KismetDatasource.SubSpecset.baseband_amp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1042,
)


_SUBSPECTRUM = _descriptor.Descriptor(
  name='SubSpectrum',
  full_name='KismetDatasource.SubSpectrum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetDatasource.SubSpectrum.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetDatasource.SubSpectrum.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_mhz', full_name='KismetDatasource.SubSpectrum.start_mhz', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_mhz', full_name='KismetDatasource.SubSpectrum.end_mhz', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bucket_width_hz', full_name='KismetDatasource.SubSpectrum.bucket_width_hz', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='KismetDatasource.SubSpectrum.data', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1169,
)


_SUBSUCCESS = _descriptor.Descriptor(
  name='SubSuccess',
  full_name='KismetDatasource.SubSuccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.SubSuccess.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seqno', full_name='KismetDatasource.SubSuccess.seqno', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1215,
)


_CLOSEDATASOURCE = _descriptor.Descriptor(
  name='CloseDatasource',
  full_name='KismetDatasource.CloseDatasource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1234,
)


_CONFIGURE = _descriptor.Descriptor(
  name='Configure',
  full_name='KismetDatasource.Configure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.Configure.channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hopping', full_name='KismetDatasource.Configure.hopping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.Configure.spectrum', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1237,
  serialized_end=1390,
)


_CONFIGUREREPORT = _descriptor.Descriptor(
  name='ConfigureReport',
  full_name='KismetDatasource.ConfigureReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.ConfigureReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.ConfigureReport.channel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hopping', full_name='KismetDatasource.ConfigureReport.hopping', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.ConfigureReport.message', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.ConfigureReport.warning', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1616,
)


_DATAREPORT = _descriptor.Descriptor(
  name='DataReport',
  full_name='KismetDatasource.DataReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gps', full_name='KismetDatasource.DataReport.gps', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.DataReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packet', full_name='KismetDatasource.DataReport.packet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='KismetDatasource.DataReport.signal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.DataReport.spectrum', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.DataReport.warning', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='json', full_name='KismetDatasource.DataReport.json', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='KismetDatasource.DataReport.buffer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='high_prec_time', full_name='KismetDatasource.DataReport.high_prec_time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1984,
)


_ERRORREPORT = _descriptor.Descriptor(
  name='ErrorReport',
  full_name='KismetDatasource.ErrorReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.ErrorReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.ErrorReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2094,
)


_LISTINTERFACES = _descriptor.Descriptor(
  name='ListInterfaces',
  full_name='KismetDatasource.ListInterfaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2112,
)


_INTERFACESREPORT = _descriptor.Descriptor(
  name='InterfacesReport',
  full_name='KismetDatasource.InterfacesReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.InterfacesReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.InterfacesReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='KismetDatasource.InterfacesReport.interfaces', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2280,
)


_NEWSOURCE = _descriptor.Descriptor(
  name='NewSource',
  full_name='KismetDatasource.NewSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='definition', full_name='KismetDatasource.NewSource.definition', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sourcetype', full_name='KismetDatasource.NewSource.sourcetype', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='KismetDatasource.NewSource.uuid', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2347,
)


_OPENSOURCE = _descriptor.Descriptor(
  name='OpenSource',
  full_name='KismetDatasource.OpenSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='definition', full_name='KismetDatasource.OpenSource.definition', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2349,
  serialized_end=2381,
)


_OPENSOURCEREPORT = _descriptor.Descriptor(
  name='OpenSourceReport',
  full_name='KismetDatasource.OpenSourceReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.OpenSourceReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dlt', full_name='KismetDatasource.OpenSourceReport.dlt', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='capture_interface', full_name='KismetDatasource.OpenSourceReport.capture_interface', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.OpenSourceReport.channels', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.OpenSourceReport.channel', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hop_config', full_name='KismetDatasource.OpenSourceReport.hop_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='KismetDatasource.OpenSourceReport.hardware', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.OpenSourceReport.message', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.OpenSourceReport.spectrum', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='KismetDatasource.OpenSourceReport.uuid', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.OpenSourceReport.warning', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2384,
  serialized_end=2780,
)


_PROBESOURCE = _descriptor.Descriptor(
  name='ProbeSource',
  full_name='KismetDatasource.ProbeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='definition', full_name='KismetDatasource.ProbeSource.definition', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2782,
  serialized_end=2815,
)


_PROBESOURCEREPORT = _descriptor.Descriptor(
  name='ProbeSourceReport',
  full_name='KismetDatasource.ProbeSourceReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='KismetDatasource.ProbeSourceReport.success', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetDatasource.ProbeSourceReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='KismetDatasource.ProbeSourceReport.channels', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='KismetDatasource.ProbeSourceReport.channel', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectrum', full_name='KismetDatasource.ProbeSourceReport.spectrum', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='KismetDatasource.ProbeSourceReport.hardware', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2818,
  serialized_end=3094,
)


_WARNINGREPORT = _descriptor.Descriptor(
  name='WarningReport',
  full_name='KismetDatasource.WarningReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetDatasource.WarningReport.warning', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3096,
  serialized_end=3128,
)

_CONFIGURE.fields_by_name['channel'].message_type = _SUBCHANSET
_CONFIGURE.fields_by_name['hopping'].message_type = _SUBCHANHOP
_CONFIGURE.fields_by_name['spectrum'].message_type = _SUBSPECSET
_CONFIGUREREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_CONFIGUREREPORT.fields_by_name['channel'].message_type = _SUBCHANSET
_CONFIGUREREPORT.fields_by_name['hopping'].message_type = _SUBCHANHOP
_CONFIGUREREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_DATAREPORT.fields_by_name['gps'].message_type = _SUBGPS
_DATAREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_DATAREPORT.fields_by_name['packet'].message_type = _SUBPACKET
_DATAREPORT.fields_by_name['signal'].message_type = _SUBSIGNAL
_DATAREPORT.fields_by_name['spectrum'].message_type = _SUBSPECTRUM
_DATAREPORT.fields_by_name['json'].message_type = _SUBJSON
_DATAREPORT.fields_by_name['buffer'].message_type = _SUBBUFFER
_ERRORREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_ERRORREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_INTERFACESREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_INTERFACESREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_INTERFACESREPORT.fields_by_name['interfaces'].message_type = _SUBINTERFACE
_OPENSOURCEREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_OPENSOURCEREPORT.fields_by_name['channels'].message_type = _SUBCHANNELS
_OPENSOURCEREPORT.fields_by_name['channel'].message_type = _SUBCHANSET
_OPENSOURCEREPORT.fields_by_name['hop_config'].message_type = _SUBCHANHOP
_OPENSOURCEREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_OPENSOURCEREPORT.fields_by_name['spectrum'].message_type = _SUBSPECSET
_PROBESOURCEREPORT.fields_by_name['success'].message_type = _SUBSUCCESS
_PROBESOURCEREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_PROBESOURCEREPORT.fields_by_name['channels'].message_type = _SUBCHANNELS
_PROBESOURCEREPORT.fields_by_name['channel'].message_type = _SUBCHANSET
_PROBESOURCEREPORT.fields_by_name['spectrum'].message_type = _SUBSPECSET
DESCRIPTOR.message_types_by_name['SubChannels'] = _SUBCHANNELS
DESCRIPTOR.message_types_by_name['SubChanset'] = _SUBCHANSET
DESCRIPTOR.message_types_by_name['SubChanhop'] = _SUBCHANHOP
DESCRIPTOR.message_types_by_name['SubGps'] = _SUBGPS
DESCRIPTOR.message_types_by_name['SubInterface'] = _SUBINTERFACE
DESCRIPTOR.message_types_by_name['SubPacket'] = _SUBPACKET
DESCRIPTOR.message_types_by_name['SubJson'] = _SUBJSON
DESCRIPTOR.message_types_by_name['SubBuffer'] = _SUBBUFFER
DESCRIPTOR.message_types_by_name['SubSignal'] = _SUBSIGNAL
DESCRIPTOR.message_types_by_name['SubSpecset'] = _SUBSPECSET
DESCRIPTOR.message_types_by_name['SubSpectrum'] = _SUBSPECTRUM
DESCRIPTOR.message_types_by_name['SubSuccess'] = _SUBSUCCESS
DESCRIPTOR.message_types_by_name['CloseDatasource'] = _CLOSEDATASOURCE
DESCRIPTOR.message_types_by_name['Configure'] = _CONFIGURE
DESCRIPTOR.message_types_by_name['ConfigureReport'] = _CONFIGUREREPORT
DESCRIPTOR.message_types_by_name['DataReport'] = _DATAREPORT
DESCRIPTOR.message_types_by_name['ErrorReport'] = _ERRORREPORT
DESCRIPTOR.message_types_by_name['ListInterfaces'] = _LISTINTERFACES
DESCRIPTOR.message_types_by_name['InterfacesReport'] = _INTERFACESREPORT
DESCRIPTOR.message_types_by_name['NewSource'] = _NEWSOURCE
DESCRIPTOR.message_types_by_name['OpenSource'] = _OPENSOURCE
DESCRIPTOR.message_types_by_name['OpenSourceReport'] = _OPENSOURCEREPORT
DESCRIPTOR.message_types_by_name['ProbeSource'] = _PROBESOURCE
DESCRIPTOR.message_types_by_name['ProbeSourceReport'] = _PROBESOURCEREPORT
DESCRIPTOR.message_types_by_name['WarningReport'] = _WARNINGREPORT

SubChannels = _reflection.GeneratedProtocolMessageType('SubChannels', (_message.Message,), dict(
  DESCRIPTOR = _SUBCHANNELS,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubChannels)
  ))
_sym_db.RegisterMessage(SubChannels)

SubChanset = _reflection.GeneratedProtocolMessageType('SubChanset', (_message.Message,), dict(
  DESCRIPTOR = _SUBCHANSET,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubChanset)
  ))
_sym_db.RegisterMessage(SubChanset)

SubChanhop = _reflection.GeneratedProtocolMessageType('SubChanhop', (_message.Message,), dict(
  DESCRIPTOR = _SUBCHANHOP,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubChanhop)
  ))
_sym_db.RegisterMessage(SubChanhop)

SubGps = _reflection.GeneratedProtocolMessageType('SubGps', (_message.Message,), dict(
  DESCRIPTOR = _SUBGPS,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubGps)
  ))
_sym_db.RegisterMessage(SubGps)

SubInterface = _reflection.GeneratedProtocolMessageType('SubInterface', (_message.Message,), dict(
  DESCRIPTOR = _SUBINTERFACE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubInterface)
  ))
_sym_db.RegisterMessage(SubInterface)

SubPacket = _reflection.GeneratedProtocolMessageType('SubPacket', (_message.Message,), dict(
  DESCRIPTOR = _SUBPACKET,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubPacket)
  ))
_sym_db.RegisterMessage(SubPacket)

SubJson = _reflection.GeneratedProtocolMessageType('SubJson', (_message.Message,), dict(
  DESCRIPTOR = _SUBJSON,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubJson)
  ))
_sym_db.RegisterMessage(SubJson)

SubBuffer = _reflection.GeneratedProtocolMessageType('SubBuffer', (_message.Message,), dict(
  DESCRIPTOR = _SUBBUFFER,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubBuffer)
  ))
_sym_db.RegisterMessage(SubBuffer)

SubSignal = _reflection.GeneratedProtocolMessageType('SubSignal', (_message.Message,), dict(
  DESCRIPTOR = _SUBSIGNAL,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSignal)
  ))
_sym_db.RegisterMessage(SubSignal)

SubSpecset = _reflection.GeneratedProtocolMessageType('SubSpecset', (_message.Message,), dict(
  DESCRIPTOR = _SUBSPECSET,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSpecset)
  ))
_sym_db.RegisterMessage(SubSpecset)

SubSpectrum = _reflection.GeneratedProtocolMessageType('SubSpectrum', (_message.Message,), dict(
  DESCRIPTOR = _SUBSPECTRUM,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSpectrum)
  ))
_sym_db.RegisterMessage(SubSpectrum)

SubSuccess = _reflection.GeneratedProtocolMessageType('SubSuccess', (_message.Message,), dict(
  DESCRIPTOR = _SUBSUCCESS,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.SubSuccess)
  ))
_sym_db.RegisterMessage(SubSuccess)

CloseDatasource = _reflection.GeneratedProtocolMessageType('CloseDatasource', (_message.Message,), dict(
  DESCRIPTOR = _CLOSEDATASOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.CloseDatasource)
  ))
_sym_db.RegisterMessage(CloseDatasource)

Configure = _reflection.GeneratedProtocolMessageType('Configure', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGURE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.Configure)
  ))
_sym_db.RegisterMessage(Configure)

ConfigureReport = _reflection.GeneratedProtocolMessageType('ConfigureReport', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGUREREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ConfigureReport)
  ))
_sym_db.RegisterMessage(ConfigureReport)

DataReport = _reflection.GeneratedProtocolMessageType('DataReport', (_message.Message,), dict(
  DESCRIPTOR = _DATAREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.DataReport)
  ))
_sym_db.RegisterMessage(DataReport)

ErrorReport = _reflection.GeneratedProtocolMessageType('ErrorReport', (_message.Message,), dict(
  DESCRIPTOR = _ERRORREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ErrorReport)
  ))
_sym_db.RegisterMessage(ErrorReport)

ListInterfaces = _reflection.GeneratedProtocolMessageType('ListInterfaces', (_message.Message,), dict(
  DESCRIPTOR = _LISTINTERFACES,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ListInterfaces)
  ))
_sym_db.RegisterMessage(ListInterfaces)

InterfacesReport = _reflection.GeneratedProtocolMessageType('InterfacesReport', (_message.Message,), dict(
  DESCRIPTOR = _INTERFACESREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.InterfacesReport)
  ))
_sym_db.RegisterMessage(InterfacesReport)

NewSource = _reflection.GeneratedProtocolMessageType('NewSource', (_message.Message,), dict(
  DESCRIPTOR = _NEWSOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.NewSource)
  ))
_sym_db.RegisterMessage(NewSource)

OpenSource = _reflection.GeneratedProtocolMessageType('OpenSource', (_message.Message,), dict(
  DESCRIPTOR = _OPENSOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.OpenSource)
  ))
_sym_db.RegisterMessage(OpenSource)

OpenSourceReport = _reflection.GeneratedProtocolMessageType('OpenSourceReport', (_message.Message,), dict(
  DESCRIPTOR = _OPENSOURCEREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.OpenSourceReport)
  ))
_sym_db.RegisterMessage(OpenSourceReport)

ProbeSource = _reflection.GeneratedProtocolMessageType('ProbeSource', (_message.Message,), dict(
  DESCRIPTOR = _PROBESOURCE,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ProbeSource)
  ))
_sym_db.RegisterMessage(ProbeSource)

ProbeSourceReport = _reflection.GeneratedProtocolMessageType('ProbeSourceReport', (_message.Message,), dict(
  DESCRIPTOR = _PROBESOURCEREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.ProbeSourceReport)
  ))
_sym_db.RegisterMessage(ProbeSourceReport)

WarningReport = _reflection.GeneratedProtocolMessageType('WarningReport', (_message.Message,), dict(
  DESCRIPTOR = _WARNINGREPORT,
  __module__ = 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:KismetDatasource.WarningReport)
  ))
_sym_db.RegisterMessage(WarningReport)


# @@protoc_insertion_point(module_scope)



# Python implementation of the simple API for communicating with Kismet
# via the Kismet External API
#
# (c) 2018 Mike Kershaw / Dragorn
# Licensed under GPL2 or above

"""
Kismet external helper API implementation

Protobuf based communication with the Kismet server for external tools interface,
datasource capture, etc.

Datasources are expanded in KismetDatasource.py
"""

import errno
import fcntl
import os
import select
import socket
import struct
import threading
import time

from . import kismet_pb2
from . import http_pb2
from . import datasource_pb2

__version__ = "2019.05.01"

class ExternalInterface(object):
    """ 
    External interface super-class
    """
    def __init__(self, infd=-1, outfd=-1, remote=None):
        """
        Initialize the external interface; interfaces launched by Kismet are 
        mapped to a pipe passed via --in-fd and --out-fd arguments; remote
        interfaces are initialized with a host:port

        :param infd: input FD, from --in-fd argument
        :param outfd: output FD, from --out-fd argument
        :param remote: remote host:port, from --connect argument
        :return: nothing
        """

        self.infd = infd
        self.outfd = outfd
        self.remote = remote
        self.remote_sock = None
        self.cmdnum = 0
        self.iothread = None

        self.debug = False

        if self.infd is not None and self.infd >= 0 and self.outfd is not None and self.outfd >= 0:
            fl = fcntl.fcntl(infd, fcntl.F_GETFL)
            fcntl.fcntl(infd, fcntl.F_SETFL, fl | os.O_NONBLOCK)

            fl = fcntl.fcntl(outfd, fcntl.F_GETFL)
            fcntl.fcntl(outfd, fcntl.F_SETFL, fl | os.O_NONBLOCK)
        elif remote is not None:
            self.__connect_remote(remote)
        else:
            raise RuntimeError("Expected descriptor pair or remote connection")

        self.wbuffer = bytearray()
        self.rbuffer = bytearray()

        self.bufferlock = threading.RLock()

        self.graceful_spindown = False
        self.kill_ioloop = False

        self.last_pong = 0

        self.running = False

        self.http_auth_callback = None
        self.auth_token = None

        self.errorcb = None

        self.handlers = {}

        self.add_handler("HTTPAUTH", self.__handle_http_auth)
        self.add_handler("HTTPREQUEST", self.__handle_http_request)
        self.add_handler("PING", self.__handle_ping)
        self.add_handler("PONG", self.__handle_pong)
        self.add_handler("SHUTDOWN", self.__handle_shutdown)

        self.uri_handlers = {}

        self.MSG_INFO = kismet_pb2.MsgbusMessage.INFO
        self.MSG_ERROR = kismet_pb2.MsgbusMessage.ERROR
        self.MSG_ALERT = kismet_pb2.MsgbusMessage.ALERT
        self.MSG_FATAL = kismet_pb2.MsgbusMessage.FATAL

    def __connect_remote(self, remote):
        eq = remote.find(":")

        if eq == -1:
            raise RuntimeError("Expected host:port for remote")

        self.remote_host = remote[:eq]
        self.remote_port = int(remote[eq+1:])

        self.remote_sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.remote_sock.connect((self.remote_host, self.remote_port))

        fl = fcntl.fcntl(self.remote_sock, fcntl.F_GETFL)
        fcntl.fcntl(self.remote_sock, fcntl.F_SETFL, fl | os.O_NONBLOCK)

    @staticmethod
    def adler32(data):
        """
        Compute an adler32 checksum

        :param data: Data to be checksummed

        :return: uint32 adler32 checksum
        """
        if len(data) < 4:
            return 0

        s1 = 0
        s2 = 0

        last_i = 0

	# Handle both str and bytearray for when we checksum the name of devices
        if type(data) == type(""):
            for i in range(0, len(data) - 4, 4):
                s2 += 4 * (s1 + ord(data[i])) + 3 * ord(data[i + 1]) + 2 * ord(data[i + 2]) + ord(data[i + 3])
                s1 += ord(data[i + 0]) + ord(data[i + 1]) + ord(data[i + 2]) + ord(data[i + 3])
                last_i = i + 4

            for i in range(last_i, len(data)):
                s1 += ord(data[i])
                s2 += s1
        else:
            for i in range(0, len(data) - 4, 4):
                s2 += 4 * (s1 + data[i]) + 3 * data[i + 1] + 2 * data[i + 2] + data[i + 3]
                s1 += data[i + 0] + data[i + 1] + data[i + 2] + data[i + 3]
                last_i = i + 4

            for i in range(last_i, len(data)):
                s1 += data[i]
                s2 += s1


        return ((s1 & 0xFFFF) + (s2 << 16)) & 0xFFFFFFFF

    def __io_loop(self):
        try:
            while not self.kill_ioloop:
                if not self.last_pong == 0 and time.time() - self.last_pong > 5:
                    raise RuntimeError("No PONG from remote system in 5 seconds")

                if self.graceful_spindown and len(self.wbuffer) == 0:
                    self.kill_ioloop = True
                    return

                if self.infd >= 0:
                    in_fd_alias = self.infd
                elif self.remote_sock is not None:
                    in_fd_alias = self.remote_sock
                else:
                    raise RuntimeError("No valid input socket")

                if self.outfd >= 0:
                    out_fd_alias = self.outfd
                elif self.remote_sock is not None:
                    out_fd_alias = self.remote_sock
                else:
                    raise RuntimeError("No valid input socket")

                inputs = [in_fd_alias]
                outputs = []

                self.bufferlock.acquire()
                try:
                    if len(self.wbuffer):
                        outputs = [out_fd_alias]
                finally:
                    self.bufferlock.release()

                (readable, writable, exceptional) = select.select(inputs, outputs, inputs, 1)

                if out_fd_alias in exceptional or in_fd_alias in exceptional:
                    raise BufferError("Buffer error:  Socket closed")

                if out_fd_alias in outputs:
                    self.bufferlock.acquire()
                    try:
                        if out_fd_alias == self.remote_sock:
                            written = self.remote_sock.send(self.wbuffer)
                        else:
                            written = os.write(out_fd_alias, self.wbuffer)

                        if written == 0:
                            raise BufferError("Output connection closed")

                        self.wbuffer = self.wbuffer[written:]
                    except OSError as e:
                        if not e.errno == errno.EAGAIN:
                            raise BufferError("Output buffer error: {}".format(e))
                    finally:
                        self.bufferlock.release()

                if in_fd_alias in inputs:
                    self.bufferlock.acquire()
                    try:
                        if in_fd_alias == self.remote_sock:
                            readdata = self.remote_sock.recv(4096)
                        else:
                            readdata = os.read(in_fd_alias, 4096)

                        if not readdata:
                            raise BufferError("Input connection closed")

                        self.rbuffer.extend(readdata)
                        self.__recv_packet()
                    except IOError as e:
                        if not e.errno == errno.EWOULDBLOCK:
                            raise BufferError("Input buffer error: {}".format(e))
                    except OSError as e:
                        if not e.errno == errno.EAGAIN:
                            raise BufferError("Input buffer error: {}".format(e))
                    finally:
                        self.bufferlock.release()
        except BufferError as e:
            # Fail out
            pass
        finally:
            self.running = False

    def __recv_packet(self):
        if len(self.rbuffer) < 12:
            return

        (signature, checksum, sz) = struct.unpack("!III", self.rbuffer[:12])

        if not signature == 0xDECAFBAD:
            raise BufferError("Invalid signature in packet header")

        if len(self.rbuffer) < 12 + sz:
            return

        content = self.rbuffer[12:(12 + sz)]

        calc_csum = ExternalInterface.adler32(content)

        if not calc_csum == checksum:
            print(content.encode('hex'))
            raise BufferError("Invalid checksum in packet header {} vs {}".format(calc_csum, checksum))

        cmd = kismet_pb2.Command()
        cmd.ParseFromString(content)

        if self.debug:
            print("KISMETEXTERNAL - CMD {}".format(cmd.command))

        if cmd.command in self.handlers:
            self.handlers[cmd.command](cmd.seqno, cmd.content)
        else:
            print("Unhandled", cmd.command)

        self.rbuffer = self.rbuffer[12 + sz:]

    @staticmethod
    def get_etc():
        """
        Get the etc directory from Kismet by querying the KISMET_ETC env variable

        :return: Path to etc (or blank)
        """
        if "KISMET_ETC" in os.environ:
            return os.environ["KISMET_ETC"]

        return ""

    def start(self):
        """
        Start the main service loop; this handles input/out from the Kismet server
        and will call registered callbacks for functions.

        :return: None
        """

        self.running = True
        self.iothread = threading.Thread(target=self.__io_loop)
        self.iothread.daemon = True
        self.iothread.start()

    def add_handler(self, command, handler):
        """
        Register a command handler; this handler will be called when a command
        is received.

        :param command: Command (string, case sensitive)
        :param handler: Handler function which will be called with (sequence number, payload)
        :return: None
        """
        self.handlers[command] = handler

    def add_uri_handler(self, method, uri, handler):
        """
        Register a URI handler with Kismet; this will be called whenever that URI is 
        triggered on the Kismet REST interface.  A URI should be a complete path, and
        include the file extension.

        :param method: HTTP method (GET or POST)
        :param uri: Full URI
        :param handler: Handler function, called with http_pb2.HttpRequest object)
        :return: None
        """

        if method not in self.uri_handlers:
            self.uri_handlers[method] = {}

        if uri not in self.uri_handlers[method]:
            self.uri_handlers[method][uri] = handler

        reguri = http_pb2.HttpRegisterUri()
        reguri.method = method
        reguri.uri = uri

        self.write_ext_packet("HTTPREGISTERURI", reguri)

    def is_running(self):
        """
        Is the external interface service running?

        :return: boolean
        """
        return self.running

    def kill(self):
        """
        Shutdown the external interface service

        :return: None
        """
        self.bufferlock.acquire()
        try:
            self.kill_ioloop = True
        finally:
            self.bufferlock.release()

    def spindown(self):
        """
        Shutdown the interface service once all pending data has been written

        :return: None
        """
        self.bufferlock.acquire()
        try:
            self.graceful_spindown = True
        finally:
            self.bufferlock.release()

    def write_raw_packet(self, kedata):
        """
        Wrap a raw piece of data in a Kismet external interface frame and write it; 
        this data must be a serialized kismet_pb2.Command frame.

        :param kedata: Serialized kismet_pb2.Command data

        :return: None
        """
        signature = 0xDECAFBAD
        serial = bytearray(kedata.SerializeToString())

        checksum = ExternalInterface.adler32(serial)
        length = len(serial)

        packet = bytearray(struct.pack("!III", signature, checksum, length))

        self.bufferlock.acquire()
        try:
            self.wbuffer.extend(packet)
            self.wbuffer.extend(serial)
        finally:
            self.bufferlock.release()

    def write_ext_packet(self, cmdtype, content):
        """
        Generate a Kismet external interface command, frame, and transmit it.

        :param cmdtype: Command type string
        :param content: Command content, must be a serializable protobuf object

        :return: None
        """
        cp = kismet_pb2.Command()

        cp.command = cmdtype
        cp.seqno = self.cmdnum
        cp.content = content.SerializeToString()

        self.write_raw_packet(cp)

        self.cmdnum = self.cmdnum + 1

    def send_message(self, message, msgtype=kismet_pb2.MsgbusMessage.INFO):
        """
        Send a message which wil be displayed via the Kismet message bus and in the UI

        :param message: Message text
        :param msgtype: message type, one of MSG_INFO, _ERROR, _ALERT, _FATAL

        :return: None
        """
        msg = kismet_pb2.MsgbusMessage()
        msg.msgtext = message
        msg.msgtype = msgtype
        self.write_ext_packet("MESSAGE", msg)

    def send_ping(self):
        """
        Send a PING

        :return: None
        """
        if self.last_pong == 0:
            self.last_pong = time.time()

        ping = kismet_pb2.Ping()
        self.write_ext_packet("PING", ping)

    def __send_pong(self, seqno):
        pong = kismet_pb2.Pong()
        pong.ping_seqno = seqno
        self.write_ext_packet("PONG", pong)

    def request_http_auth(self, callback=None):
        """
        Request Kismet generate a HTTP session token; this token will be sent
        via a HTTPAUTH message and the callback function will be triggered.

        :param callback: Function to be called when an AUTH result is returned,
        called with no parameters.

        :return: None
        """
        self.http_auth_callback = callback
        auth = http_pb2.HttpAuthTokenRequest()
        self.write_ext_packet("HTTPAUTHREQ", auth)

    def __handle_http_auth(self, seqno, packet):
        auth = http_pb2.HttpAuthToken()
        auth.ParseFromString(packet)
        self.auth_token = auth.token

        if self.http_auth_callback is not None:
            self.http_auth_callback()

    def __handle_http_request(self, seqno, packet):
        request = http_pb2.HttpRequest()
        request.ParseFromString(packet)

        if request.method not in self.uri_handlers:
            raise RuntimeError("No URI handler registered for request {} {}".format(request.method, request.uri))

        if request.uri not in self.uri_handlers[request.method]:
            raise RuntimeError("No URI handler registered for request {} {}".format(request.method, request.uri))
        self.uri_handlers[request.method][request.uri](self, request)

    def send_http_response(self, req_id, data="", resultcode=200, stream=False, finished=True):
        """
        Send a HTTP response; this populates a URI when triggered.

        Responses may include the entire data to be sent, or may be streamed (if stream = True).

        This may be called many times for the same req_id, to send large results, or streaming
        results.

        A response is not closed until finished = True.

        :param req_id: HTTP request ID, provided in the HttpRequest message.  This must be sent with
        every response which is part of the same request.
        :param data: HTTP data to be sent.  This may be broken up into multiple response objects
        automatically.
        :param resultcode: HTTP result code; the result code in the final response (finished = True)
        is sent as the final HTTP code.
        :param stream: This response is one of many in a stream, the connection will be held open
        until a send_http_response with finished = False
        :param finished: This is the last response of many in a stream, the connection will be closed.
        """
        resp = http_pb2.HttpResponse()

        # Set the response
        resp.req_id = req_id

        # Break the data into chunks and send each chunk as part of the response
        for block in range(0, len(data), 1024):
            resp.content = data[block:block+1024]
            self.write_ext_packet("HTTPRESPONSE", resp)

        # Do we finish it up?
        if not stream or (stream and finished):
            resp.content = ""
            resp.resultcode = resultcode
            resp.close_response = True
            self.write_ext_packet("HTTPRESPONSE", resp)

    def __handle_ping(self, seqno, packet):
        ping = kismet_pb2.Ping()
        ping.ParseFromString(packet)

        self.__send_pong(seqno)

    def __handle_pong(self, seqno, packet):
        pong = kismet_pb2.Pong()
        pong.ParseFromString(packet)

        self.last_pong = time.time()

    def __handle_shutdown(self, seqno, packet):
        shutdown = kismet_pb2.ExternalShutdown()
        shutdown.ParseFromString(packet)
        self.kill()


class Datasource(ExternalInterface):
    """ 
    Datasource implementation
    """
    def __init__(self, infd=-1, outfd=-1, remote=None):
        super(Datasource, self).__init__(infd=infd, outfd=outfd, remote=remote)

        self.listinterfaces = None
        self.probesource = None
        self.opensource = None
        self.configuresource = None

        self.add_handler("KDSCONFIGURE", self.__handle_kds_configure)
        self.add_handler("KDSLISTINTERFACES", self.__handle_kds_listinterfaces)
        self.add_handler("KDSOPENSOURCE", self.__handle_kds_opensource)
        self.add_handler("KDSPROBESOURCE", self.__handle_kds_probesource)

    @staticmethod
    def make_uuid(driver, address):
        """
        Generate a UUID

        :param driver: Driver component, will be hashed
        :param address: Address component, must be 6 bytes of hex (12 characters)

        :return: UUID string
        """
        driverhex = "{:02X}".format(ExternalInterface.adler32(bytearray(driver)))
        return "{}-0000-0000-0000-{}".format(driverhex[:8], address[:12])

    def set_listinterfaces_cb(self, cb):
        """
        Set callback to support datasource listsources command

        :param cb: Callback function, taking seqno, source definition, option map

        :return: None
        """
        self.listinterfaces = cb

    def set_probesource_cb(self, cb):
        """
        Set callback for datasource probing

        :param cb: Callback function, taking seqno, source definition, option map

        :return: None
        """
        self.probesource = cb

    def set_opensource_cb(self, cb):
        """
        Set callback for datasource opening

        :param cb: Callback function, taking seqno, source definition, option map

        :return: None
        """
        self.opensource = cb

    def set_configsource_cb(self, cb):
        """
        Set callback for source configuring

        :param cb: Callback function, taking seqno and datasource_pb2.Configure record

        :return: None
        """
        self.configuresource = cb

    @staticmethod
    def parse_definition(definition):
        """
        Parse a Kismet definition into a (source, optionsmap) tuple

        :param definition: Kismet source definition

        :return: (source, options{} dictionary) as tuple
        """
        options = {}
    
        colon = definition.find(':')
    
        if colon == -1:
            return definition, {}
    
        source = definition[:colon]
        right = definition[colon + 1:]
    
        while len(right):
            eqpos = right.find('=')
            if eqpos == -1:
                return None, None
    
            key = right[:eqpos]
            right = right[eqpos + 1:]
    
            # If we're quoted
            if right[0] == '"':
                right = right[1:]
                endq = right.find('"')
    
                if endq == -1:
                    return None, None
    
                val = right[:endq]
                options[key] = val
                right = right[endq + 1:]
            else:
                endcomma = right.find(',')

                if endcomma == -1:
                    endcomma = len(right)
    
                val = right[:endcomma]
                options[key] = val
                right = right[endcomma + 1:]
    
        return source, options

    def __handle_kds_configure(self, seqno, packet):
        conf = datasource_pb2.Configure()
        conf.ParseFromString(packet)

        if self.configuresource is None:
            self.send_datasource_configure_report(seqno, success=False,
                                                  message="helper does not support source configuration")
            # self.spindown()
            return
            
        opts = self.configuresource(seqno, conf)
        
        if opts is None:
            self.send_datasource_configure_report(seqno, success=False,
                                                  message="helper does not support source configuration")
            # self.spindown()
            return

        self.send_datasource_configure_report(seqno, **opts)

    def __handle_kds_opensource(self, seqno, packet):
        opensource = datasource_pb2.OpenSource()
        opensource.ParseFromString(packet)

        (source, options) = self.parse_definition(opensource.definition)

        if self.opensource is None:
            self.send_datasource_open_report(seqno, success=False,
                                             message="helper does not support opening sources")
            # self.spindown()
            return

        opts = self.opensource(source, options)

        if opts is None:
            self.send_datasource_open_report(seqno, success=False,
                                             message="helper does not support opening sources")

        self.send_datasource_open_report(seqno, **opts)

    def __handle_kds_probesource(self, seqno, packet):
        probe = datasource_pb2.ProbeSource()
        probe.ParseFromString(packet)

        (source, options) = self.parse_definition(probe.definition)

        if source is None:
            self.send_datasource_probe_report(seqno, success=False)
            return

        if self.probesource is None:
            self.send_datasource_probe_report(seqno, success=False)
            # self.spindown()
            return

        opts = self.probesource(source, options)

        if opts is None:
            self.send_datasource_probe_report(seqno, success=False)
            # self.spindown()
            return

        self.send_datasource_probe_report(seqno, **opts)

        # self.spindown()

    def __handle_kds_listinterfaces(self, seqno, packet):
        cmd = datasource_pb2.ListInterfaces()
        cmd.ParseFromString(packet)

        if self.listinterfaces is None:
            self.send_datasource_interfaces_report(seqno, success=True)
        else:
            self.listinterfaces(seqno)

        # self.spindown()

    def send_datasource_error_report(self, seqno=0, message=None):
        """
        When acting as a Kismet datasource, send a source error.  This can be in response
        to a specific command, or a runtime failure.

        :param seqno: Command which failed, or 0
        :param message: Optional user message

        :return: None
        """

        report = datasource_pb2.ErrorReport()

        report.success.success = False
        report.success.seqno = seqno

        if message is not None:
            report.message.msgtext = message
            report.message.msgtype = self.MSG_ERROR

        self.write_ext_packet("KDSERROR", report)

        # self.spindown()

    def send_datasource_interfaces_report(self, seqno, interfaces=None, success=True, message=None):
        """
        When acting as a Kismet datasource, send a list of supported interfaces.  This
        should be called from a child implementation of this class which implements the
        datasource_listinterfaces function.

        :param seqno: Sequence number of the interface list request
        :param interfaces: Array of datasource_pb.SubInterface responses
        :param success: Successful completion of request; a source with no interfaces is not
        a failure, and should return an empty interfaces list.
        :param message: Optional user message

        :return: None
        """
        report = datasource_pb2.InterfacesReport()

        report.success.success = success
        report.success.seqno = seqno

        if message is not None:
            report.message.msgtext = message
            if success:
                report.message.msgtype = self.MSG_INFO
            else:
                report.message.msgtype = self.MSG_ERROR

        if interfaces is not None:
            report.interfaces.extend(interfaces)

        self.write_ext_packet("KDSINTERFACESREPORT", report)

    def send_datasource_newsource(self, definition, sourcetype, uuid):
        """
        When acting as a Kismet datasource, via a remote TCP connection, datasources must
        tell Kismet the type of source to create via a Newsource command.

        :param definition: Source definition line
        :param sourcetype: Source driver type
        :param uuid: Source UUID

        :return: None
        """
        newsource = datasource_pb2.NewSource()

        newsource.definition = definition
        newsource.sourcetype = sourcetype
        newsource.uuid = uuid

        self.write_ext_packet("KDSNEWSOURCE", newsource)

    def send_datasource_configure_report(self, seqno, success=False, channel=None, hop_rate=None,
                                         hop_channels=None, spectrum=None, message=None,
                                         full_hopping=None, warning=None, **kwargs):
        """
        When acting as a Kismet datasource, send a response to a configuration request.  This
        is called with the response to the open datasource command.

        :param seqno: Sequence number of open source command
        :param success: Source configuration success
        :param channel: Optional source single-channel configuration
        :param hop_rate: Optional source hop speed, if hopping
        :param hop_channels: Optional vector of string channels, if hopping
        :param message: Optional message
        :param full_hopping: Optional full datasource_pb2.SubChanset
        :param warning: Optional warning text to be set in datasource detailed info
        :param spectrum: Optional spectral data
        :param kwargs: Unused additional arguments

        :return: None
        """

        report = datasource_pb2.ConfigureReport()

        report.success.success = success
        report.success.seqno = seqno

        if message:
            report.message.msgtext = message
            if success:
                report.message.msgtype = self.MSG_INFO
            else:
                report.message.msgtype = self.MSG_ERROR

        if hop_channels:
            report.hopping.channels.extend(hop_channels)

        if hop_rate:
            report.hopping.hop_rate = hop_rate

        if channel:
            report.channel.channel = channel

        if full_hopping:
            report.hopping.CopyFrom(full_hopping)

        if spectrum:
            report.spectrum.CopyFrom(spectrum)

        if warning:
            report.warning = warning

        self.write_ext_packet("KDSCONFIGUREREPORT", report)


    def send_datasource_open_report(self, seqno, success=False, dlt=0, capture_interface=None, channels=None,
                                    channel=None, hop_config=None, hardware=None, message=None, spectrum=None,
                                    uuid=None, warning=None, **kwargs):
        """
        When acting as a Kismet datasource, send a response to an open source request.  This is
        called with the response to the open datasource command.

        :param seqno: Sequence number of open source command
        :param success: Source open success
        :param dlt: DLT/Data link type of packets from source
        :param capture_interface: Optional interface for capture, if not the same as specified in open
        :param channels: Optional array of channel supported channels
        :param channel: Optional single channel source will tune to
        :param hop_config: datasource_pb2.SubChanhop record of initial hopping configuration
        :param hardware: Optional hardware/chipset information
        :param message: Optional user message
        :param spectrum: Optional datasource_pb2.SubSpecset initial spectrum configuration
        :param uuid: Optional UUID
        :param warning: Optional warning
        :param kwargs: Unused additional arguments

        :return: None
        """

        report = datasource_pb2.OpenSourceReport()

        report.success.success = success
        report.success.seqno = seqno

        if message is not None:
            report.message.msgtext = message
            if success:
                report.message.msgtype = self.MSG_INFO
            else:
                report.message.msgtype = self.MSG_ERROR

        if channels is not None:
            report.channels.channels.extend(channels)

        if channel is not None:
            report.channel.channel = channel

        if spectrum is not None:
            report.spectrum.CopyFrom(spectrum)

        if hardware is not None:
            report.hardware = hardware

        report.dlt = dlt

        if capture_interface is not None:
            report.capture_interface = capture_interface

        if hop_config is not None:
            report.hop_config.CopyFrom(hop_config)

        if uuid is not None:
            report.uuid = uuid

        if warning is not None:
            report.warning = warning

        self.write_ext_packet("KDSOPENSOURCEREPORT", report)

    def send_datasource_probe_report(self, seqno, success=False, message=None, channels=None, channel=None,
                                     spectrum=None, hardware=None, **kwargs):
        """
        When operating as a Kismet datasource, send a probe source report; this is used to
        determine the datasource driver.  This should be called by child implementations
        of this class from the datasource_probesource function.

        :param seqno: Sequence number of PROBESOURCE command
        :param success: Successful probing of source; sources which cannot be probed
        should return False here.
        :param message: Optional user message; typically sources should not need to send
        a message in a failure condition as they may be probing multiple source types.
        :param channels: Optional list of supported channels
        :param channel: Optional single supported channel
        :param spectrum: Optional datasource_pb2.SubSpecset spectrum support
        :param hardware: Optional hardware/chipset information
        :param **kwargs: Extraneous command options

        :return: None
        """

        report = datasource_pb2.ProbeSourceReport()

        report.success.success = success
        report.success.seqno = seqno

        if message is not None:
            report.message.msgtext = message
            if success:
                report.message.msgtype = self.MSG_INFO
            else:
                report.message.msgtype = self.MSG_ERROR

        if channels is not None:
            report.channels.channels.extend(channels)

        if channel is not None:
            report.channel.channel = channel

        if spectrum is not None:
            report.spectrum.CopyFrom(spectrum)

        if hardware is not None:
            report.hardware = hardware

        self.write_ext_packet("KDSPROBESOURCEREPORT", report)

    def send_datasource_warning_report(self, seqno, warning):
        """
        When operating as a Kismet datasource, set a warning message; this is shown in the
        Datasources display, and indicates a non-fatal but otherwise "bad" condition.

        :param seqno: (unused) sequence number
        :param warning: Warning message

        :return: None
        """

        report = datasource_pb2.WarningReport()
        report.warning = warning

        self.write_ext_packet("KDSWARNINGREPORT", report)

    def send_datasource_data_report(self, message=None, warning=None, full_gps=None, full_signal=None, full_packet=None,
                                    full_spectrum=None, full_json=None, full_buffer=None, **kwargs):
        """
        When operating as a Kismet datasource, send a data frame

        :param message: Optional message
        :param warning: Optional warning to be included in the datasource details
        :param full_gps: Optional full datasource_pb2.SubGps record
        :param full_signal: Optional full datasource_pb2.SubSignal record
        :param full_spectrum: Optional full datasource_pb2 SubSpectrum record
        :param full_packet: Optional full datasource_pb2.SubPacket record
        :param full_json: Optional JSON record
        :param full_buffer: Optional protobuf packed buffer

        :return: None
        """

        report = datasource_pb2.DataReport()

        if message is not None:
            report.message.msgtext = message
            report.message.msgtype = self.MSG_INFO

        if full_gps:
            report.gps.CopyFrom(full_gps)

        if full_signal:
            report.signal.CopyFrom(full_signal)

        if full_spectrum:
            report.signal.CopyFrom(full_spectrum)

        if full_packet:
            report.packet.CopyFrom(full_packet)

        if full_json:
            report.json.CopyFrom(full_json)

        if full_buffer:
            report.buffer.CopyFrom(full_buffer)

        if warning:
            report.warning = warning

        self.write_ext_packet("KDSDATAREPORT", report)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: http.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='http.proto',
  package='KismetExternalHttp',
  syntax='proto2',
  serialized_pb=_b('\n\nhttp.proto\x12\x12KismetExternalHttp\"\x16\n\x14HttpAuthTokenRequest\"\x1e\n\rHttpAuthToken\x12\r\n\x05token\x18\x01 \x02(\t\"N\n\x0fHttpRegisterUri\x12\x0b\n\x03uri\x18\x01 \x02(\t\x12\x0e\n\x06method\x18\x02 \x02(\t\x12\x1e\n\x16obsolete_auth_required\x18\x03 \x01(\x08\"5\n\x13SubHttpVariableData\x12\r\n\x05\x66ield\x18\x01 \x02(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x02(\t\"z\n\x0bHttpRequest\x12\x0e\n\x06req_id\x18\x01 \x02(\r\x12\x0b\n\x03uri\x18\x02 \x02(\t\x12\x0e\n\x06method\x18\x03 \x02(\t\x12>\n\rvariable_data\x18\x04 \x03(\x0b\x32\'.KismetExternalHttp.SubHttpVariableData\"#\n\x11HttpRequestCancel\x12\x0e\n\x06req_id\x18\x01 \x02(\r\"0\n\rSubHttpHeader\x12\x0e\n\x06header\x18\x01 \x02(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x02(\t\"\x96\x01\n\x0cHttpResponse\x12\x0e\n\x06req_id\x18\x01 \x02(\r\x12\x39\n\x0eheader_content\x18\x02 \x03(\x0b\x32!.KismetExternalHttp.SubHttpHeader\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x12\n\nresultcode\x18\x04 \x01(\r\x12\x16\n\x0e\x63lose_response\x18\x05 \x01(\x08')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_HTTPAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='HttpAuthTokenRequest',
  full_name='KismetExternalHttp.HttpAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=56,
)


_HTTPAUTHTOKEN = _descriptor.Descriptor(
  name='HttpAuthToken',
  full_name='KismetExternalHttp.HttpAuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='KismetExternalHttp.HttpAuthToken.token', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=88,
)


_HTTPREGISTERURI = _descriptor.Descriptor(
  name='HttpRegisterUri',
  full_name='KismetExternalHttp.HttpRegisterUri',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='KismetExternalHttp.HttpRegisterUri.uri', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='KismetExternalHttp.HttpRegisterUri.method', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='obsolete_auth_required', full_name='KismetExternalHttp.HttpRegisterUri.obsolete_auth_required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=168,
)


_SUBHTTPVARIABLEDATA = _descriptor.Descriptor(
  name='SubHttpVariableData',
  full_name='KismetExternalHttp.SubHttpVariableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='KismetExternalHttp.SubHttpVariableData.field', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content', full_name='KismetExternalHttp.SubHttpVariableData.content', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=223,
)


_HTTPREQUEST = _descriptor.Descriptor(
  name='HttpRequest',
  full_name='KismetExternalHttp.HttpRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='KismetExternalHttp.HttpRequest.req_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uri', full_name='KismetExternalHttp.HttpRequest.uri', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='KismetExternalHttp.HttpRequest.method', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variable_data', full_name='KismetExternalHttp.HttpRequest.variable_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=347,
)


_HTTPREQUESTCANCEL = _descriptor.Descriptor(
  name='HttpRequestCancel',
  full_name='KismetExternalHttp.HttpRequestCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='KismetExternalHttp.HttpRequestCancel.req_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=384,
)


_SUBHTTPHEADER = _descriptor.Descriptor(
  name='SubHttpHeader',
  full_name='KismetExternalHttp.SubHttpHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='KismetExternalHttp.SubHttpHeader.header', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content', full_name='KismetExternalHttp.SubHttpHeader.content', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=434,
)


_HTTPRESPONSE = _descriptor.Descriptor(
  name='HttpResponse',
  full_name='KismetExternalHttp.HttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='KismetExternalHttp.HttpResponse.req_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='header_content', full_name='KismetExternalHttp.HttpResponse.header_content', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content', full_name='KismetExternalHttp.HttpResponse.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resultcode', full_name='KismetExternalHttp.HttpResponse.resultcode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='close_response', full_name='KismetExternalHttp.HttpResponse.close_response', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=587,
)

_HTTPREQUEST.fields_by_name['variable_data'].message_type = _SUBHTTPVARIABLEDATA
_HTTPRESPONSE.fields_by_name['header_content'].message_type = _SUBHTTPHEADER
DESCRIPTOR.message_types_by_name['HttpAuthTokenRequest'] = _HTTPAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['HttpAuthToken'] = _HTTPAUTHTOKEN
DESCRIPTOR.message_types_by_name['HttpRegisterUri'] = _HTTPREGISTERURI
DESCRIPTOR.message_types_by_name['SubHttpVariableData'] = _SUBHTTPVARIABLEDATA
DESCRIPTOR.message_types_by_name['HttpRequest'] = _HTTPREQUEST
DESCRIPTOR.message_types_by_name['HttpRequestCancel'] = _HTTPREQUESTCANCEL
DESCRIPTOR.message_types_by_name['SubHttpHeader'] = _SUBHTTPHEADER
DESCRIPTOR.message_types_by_name['HttpResponse'] = _HTTPRESPONSE

HttpAuthTokenRequest = _reflection.GeneratedProtocolMessageType('HttpAuthTokenRequest', (_message.Message,), dict(
  DESCRIPTOR = _HTTPAUTHTOKENREQUEST,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpAuthTokenRequest)
  ))
_sym_db.RegisterMessage(HttpAuthTokenRequest)

HttpAuthToken = _reflection.GeneratedProtocolMessageType('HttpAuthToken', (_message.Message,), dict(
  DESCRIPTOR = _HTTPAUTHTOKEN,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpAuthToken)
  ))
_sym_db.RegisterMessage(HttpAuthToken)

HttpRegisterUri = _reflection.GeneratedProtocolMessageType('HttpRegisterUri', (_message.Message,), dict(
  DESCRIPTOR = _HTTPREGISTERURI,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpRegisterUri)
  ))
_sym_db.RegisterMessage(HttpRegisterUri)

SubHttpVariableData = _reflection.GeneratedProtocolMessageType('SubHttpVariableData', (_message.Message,), dict(
  DESCRIPTOR = _SUBHTTPVARIABLEDATA,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.SubHttpVariableData)
  ))
_sym_db.RegisterMessage(SubHttpVariableData)

HttpRequest = _reflection.GeneratedProtocolMessageType('HttpRequest', (_message.Message,), dict(
  DESCRIPTOR = _HTTPREQUEST,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpRequest)
  ))
_sym_db.RegisterMessage(HttpRequest)

HttpRequestCancel = _reflection.GeneratedProtocolMessageType('HttpRequestCancel', (_message.Message,), dict(
  DESCRIPTOR = _HTTPREQUESTCANCEL,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpRequestCancel)
  ))
_sym_db.RegisterMessage(HttpRequestCancel)

SubHttpHeader = _reflection.GeneratedProtocolMessageType('SubHttpHeader', (_message.Message,), dict(
  DESCRIPTOR = _SUBHTTPHEADER,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.SubHttpHeader)
  ))
_sym_db.RegisterMessage(SubHttpHeader)

HttpResponse = _reflection.GeneratedProtocolMessageType('HttpResponse', (_message.Message,), dict(
  DESCRIPTOR = _HTTPRESPONSE,
  __module__ = 'http_pb2'
  # @@protoc_insertion_point(class_scope:KismetExternalHttp.HttpResponse)
  ))
_sym_db.RegisterMessage(HttpResponse)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: linuxbluetooth.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import kismet_pb2 as kismet__pb2
from . import datasource_pb2 as datasource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='linuxbluetooth.proto',
  package='KismetLinuxBluetooth',
  syntax='proto2',
  serialized_pb=_b('\n\x14linuxbluetooth.proto\x12\x14KismetLinuxBluetooth\x1a\x0ckismet.proto\x1a\x10\x64\x61tasource.proto\"\x8f\x01\n\x17SubLinuxBluetoothDevice\x12\x10\n\x08time_sec\x18\x01 \x02(\x04\x12\x11\n\ttime_usec\x18\x02 \x02(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x02(\t\x12\x0c\n\x04name\x18\x04 \x02(\t\x12\x0f\n\x07txpower\x18\x05 \x02(\x05\x12\x0c\n\x04type\x18\x06 \x02(\x05\x12\x11\n\tuuid_list\x18\x07 \x03(\t\"\xf0\x01\n\x18LinuxBluetoothDataReport\x12%\n\x03gps\x18\x01 \x01(\x0b\x32\x18.KismetDatasource.SubGps\x12.\n\x07message\x18\x02 \x01(\x0b\x32\x1d.KismetExternal.MsgbusMessage\x12\x0f\n\x07warning\x18\x03 \x01(\t\x12+\n\x06signal\x18\x04 \x01(\x0b\x32\x1b.KismetDatasource.SubSignal\x12?\n\x08\x62tdevice\x18\x05 \x02(\x0b\x32-.KismetLinuxBluetooth.SubLinuxBluetoothDevice')
  ,
  dependencies=[kismet__pb2.DESCRIPTOR,datasource__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SUBLINUXBLUETOOTHDEVICE = _descriptor.Descriptor(
  name='SubLinuxBluetoothDevice',
  full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.time_sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_usec', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.time_usec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='address', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.address', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.name', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='txpower', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.txpower', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.type', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid_list', full_name='KismetLinuxBluetooth.SubLinuxBluetoothDevice.uuid_list', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=222,
)


_LINUXBLUETOOTHDATAREPORT = _descriptor.Descriptor(
  name='LinuxBluetoothDataReport',
  full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gps', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.gps', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warning', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.warning', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.signal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='btdevice', full_name='KismetLinuxBluetooth.LinuxBluetoothDataReport.btdevice', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=465,
)

_LINUXBLUETOOTHDATAREPORT.fields_by_name['gps'].message_type = datasource__pb2._SUBGPS
_LINUXBLUETOOTHDATAREPORT.fields_by_name['message'].message_type = kismet__pb2._MSGBUSMESSAGE
_LINUXBLUETOOTHDATAREPORT.fields_by_name['signal'].message_type = datasource__pb2._SUBSIGNAL
_LINUXBLUETOOTHDATAREPORT.fields_by_name['btdevice'].message_type = _SUBLINUXBLUETOOTHDEVICE
DESCRIPTOR.message_types_by_name['SubLinuxBluetoothDevice'] = _SUBLINUXBLUETOOTHDEVICE
DESCRIPTOR.message_types_by_name['LinuxBluetoothDataReport'] = _LINUXBLUETOOTHDATAREPORT

SubLinuxBluetoothDevice = _reflection.GeneratedProtocolMessageType('SubLinuxBluetoothDevice', (_message.Message,), dict(
  DESCRIPTOR = _SUBLINUXBLUETOOTHDEVICE,
  __module__ = 'linuxbluetooth_pb2'
  # @@protoc_insertion_point(class_scope:KismetLinuxBluetooth.SubLinuxBluetoothDevice)
  ))
_sym_db.RegisterMessage(SubLinuxBluetoothDevice)

LinuxBluetoothDataReport = _reflection.GeneratedProtocolMessageType('LinuxBluetoothDataReport', (_message.Message,), dict(
  DESCRIPTOR = _LINUXBLUETOOTHDATAREPORT,
  __module__ = 'linuxbluetooth_pb2'
  # @@protoc_insertion_point(class_scope:KismetLinuxBluetooth.LinuxBluetoothDataReport)
  ))
_sym_db.RegisterMessage(LinuxBluetoothDataReport)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python2

import os
import re
from setuptools import setup, find_packages

def read(file_name):
    with open(os.path.join(os.path.dirname(__file__), file_name), 'r') as f:
        filestring = f.read()
    return filestring


def get_version():
    raw_init_file = read("kismetexternal/__init__.py")
    rx_compiled = re.compile(r"\s*__version__\s*=\s*\"(\S+)\"")
    ver = rx_compiled.search(raw_init_file).group(1)
    return ver

setup(name='kismetexternal',
      version=get_version(),
      description='Kismet External Helper Library',
      author='Mike Kershaw / Dragorn',
      author_email='dragorn@kismetwireless.net',
      url='https://www.kismetwireless.net/',
      install_requires=['protobuf >= 3.0.0'],
      packages=find_packages(),
     )


